import * as i0 from '@angular/core';
import { Directive, Component, Input, ViewChild, EventEmitter, NgModule } from '@angular/core';
import * as i1 from '@ng-bootstrap/ng-bootstrap';

class ModalForm {
    constructor(component, data) {
        this.component = component;
        this.data = data;
    }
}

// Angular modules
class ModalWrapperDirective {
    constructor(viewContainerRef) {
        this.viewContainerRef = viewContainerRef;
    }
}
ModalWrapperDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.3", ngImport: i0, type: ModalWrapperDirective, deps: [{ token: i0.ViewContainerRef }], target: i0.ɵɵFactoryTarget.Directive });
ModalWrapperDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "15.1.3", type: ModalWrapperDirective, selector: "[modal-wrapper-host]", ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.3", ngImport: i0, type: ModalWrapperDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[modal-wrapper-host]'
                }]
        }], ctorParameters: function () { return [{ type: i0.ViewContainerRef }]; } });

// Angular modules
class ModalWrapperComponent {
    constructor(activeModal) {
        this.activeModal = activeModal;
    }
    ngOnInit() {
        this.loadComponent();
    }
    loadComponent() {
        const modalForm = new ModalForm(this.component, this.componentData);
        const viewContainerRef = this.modalWrapperHost.viewContainerRef;
        viewContainerRef.clear();
        const component = viewContainerRef.createComponent(modalForm.component);
        component.instance.data = modalForm.data;
        component.instance.submitData.subscribe(this.activeModal.close);
        component.instance.submitClose.subscribe(this.activeModal.close);
    }
}
ModalWrapperComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.3", ngImport: i0, type: ModalWrapperComponent, deps: [{ token: i1.NgbActiveModal }], target: i0.ɵɵFactoryTarget.Component });
ModalWrapperComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.1.3", type: ModalWrapperComponent, selector: "app-modal-wrapper", inputs: { component: "component", componentData: "componentData", modalData: "modalData" }, viewQueries: [{ propertyName: "modalWrapperHost", first: true, predicate: ModalWrapperDirective, descendants: true, static: true }], ngImport: i0, template: "<div class=\"modal-header\">\n  <h6 class=\"modal-title\">{{ modalData.title }}</h6>\n  <button type=\"button\" class=\"btn-close\" aria-label=\"close\" (click)=\"activeModal.dismiss()\"></button>\n</div>\n<div class=\"modal-body auto\">\n  <ng-template modal-wrapper-host></ng-template>\n</div>", dependencies: [{ kind: "directive", type: ModalWrapperDirective, selector: "[modal-wrapper-host]" }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.3", ngImport: i0, type: ModalWrapperComponent, decorators: [{
            type: Component,
            args: [{ selector: 'app-modal-wrapper', template: "<div class=\"modal-header\">\n  <h6 class=\"modal-title\">{{ modalData.title }}</h6>\n  <button type=\"button\" class=\"btn-close\" aria-label=\"close\" (click)=\"activeModal.dismiss()\"></button>\n</div>\n<div class=\"modal-body auto\">\n  <ng-template modal-wrapper-host></ng-template>\n</div>" }]
        }], ctorParameters: function () { return [{ type: i1.NgbActiveModal }]; }, propDecorators: { component: [{
                type: Input
            }], componentData: [{
                type: Input
            }], modalData: [{
                type: Input
            }], modalWrapperHost: [{
                type: ViewChild,
                args: [ModalWrapperDirective, { static: true }]
            }] } });

// Components
class ModalBuilder {
    constructor(ngModal) {
        this.title = 'NO TITLE';
        this.force = false;
        this.ngModal = ngModal;
    }
    /**
     * Create a `ModalBuilder` used to create and configure your modal.
     * @param ngModal
     * @returns ModalBuilder
     */
    static make(ngModal) {
        return new ModalBuilder(ngModal);
    }
    /**
     * Set the modal `title`.
     * @param title
     * @returns ModalBuilder
     */
    setTitle(title) {
        this.title = title;
        return this;
    }
    /**
     * Set the `component` to place in the modal body.
     * @param component
     * @returns ModalBuilder
     */
    setComponent(component) {
        this.component = component;
        return this;
    }
    /**
     * Set the `force` behavior.
     * @param force If false, the modal can be closed by clicking on the background. (default: false)
     * @returns ModalBuilder
     */
    setForceMode(force = true) {
        this.force = force;
        return this;
    }
    /**
     * Set the modal `size`.
     * @param size
     * @returns ModalBuilder
     */
    setSize(size) {
        this.size = size;
        return this;
    }
    /**
     * Set the modal `input` to pass to the component.
     * @param input
     * @returns ModalBuilder
     */
    setInput(input) {
        this.input = input;
        return this;
    }
    /**
     * Show the modal.
     * @returns NgbTypedModalRef
     */
    show() {
        if (!this.component)
            throw new Error('missing component, setComponent was not called');
        if (typeof this.input === 'undefined')
            throw new Error('Input was `undefined`, if it\'s intended set to null instead.');
        const modalRef = this.ngModal.open(ModalWrapperComponent, {
            centered: true,
            backdrop: this.force ? 'static' : true,
            size: this.size,
            beforeDismiss: () => { modalRef.close(null); return true; } // propagate the dismiss event to close event
        });
        modalRef.componentInstance.component = this.component;
        modalRef.componentInstance.componentData = this.input;
        modalRef.componentInstance.modalData = { title: this.title };
        return modalRef;
    }
}

// Angular modules
class NgbTypedModal {
    constructor() {
        this.submitData = new EventEmitter();
        this.submitClose = new EventEmitter();
    }
    make(ngModal) {
        return ModalBuilder.make(ngModal);
    }
}

// Angular modules
class NgbTypedModalModule {
}
NgbTypedModalModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.3", ngImport: i0, type: NgbTypedModalModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
NgbTypedModalModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.1.3", ngImport: i0, type: NgbTypedModalModule, declarations: [ModalWrapperComponent,
        ModalWrapperDirective], exports: [ModalWrapperComponent] });
NgbTypedModalModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.1.3", ngImport: i0, type: NgbTypedModalModule });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.3", ngImport: i0, type: NgbTypedModalModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        ModalWrapperComponent,
                        ModalWrapperDirective
                    ],
                    exports: [
                        ModalWrapperComponent
                    ]
                }]
        }] });

/*
 * Public API Surface of ngx-bootstrap-typed-modal
 */

/**
 * Generated bundle index. Do not edit.
 */

export { ModalBuilder, ModalWrapperComponent, NgbTypedModal, NgbTypedModalModule };
//# sourceMappingURL=ngx-bootstrap-typed-modal.mjs.map
