import { Type } from '@angular/core';
import { NgbTypedModalRef } from '../types/ngb-typed-modal-ref.type';
import { NgbModal } from '@ng-bootstrap/ng-bootstrap';
export declare class ModalBuilder<Component, Input, Output> {
    private ngModal;
    private title;
    private component?;
    private input?;
    private size?;
    private force?;
    constructor(ngModal: NgbModal);
    /**
     * Create a `ModalBuilder` used to create and configure your modal.
     * @param ngModal
     * @returns ModalBuilder
     */
    static make<Component, Input, Output>(ngModal: NgbModal): ModalBuilder<Component, Input, Output>;
    /**
     * Set the modal `title`.
     * @param title
     * @returns ModalBuilder
     */
    setTitle(title: string): this;
    /**
     * Set the `component` to place in the modal body.
     * @param component
     * @returns ModalBuilder
     */
    setComponent(component: Type<Component>): this;
    /**
     * Set the `force` behavior.
     * @param force If false, the modal can be closed by clicking on the background. (default: false)
     * @returns ModalBuilder
     */
    setForceMode(force?: boolean): this;
    /**
     * Set the modal `size`.
     * @param size
     * @returns ModalBuilder
     */
    setSize(size: 'sm' | 'lg' | 'xl'): this;
    /**
     * Set the modal `input` to pass to the component.
     * @param input
     * @returns ModalBuilder
     */
    setInput(input: Input): this;
    /**
     * Show the modal.
     * @returns NgbTypedModalRef
     */
    show(): Omit<NgbTypedModalRef<Component, Input, Output>, 'componentInstance'>;
}
